*************
API Reference
*************

Serializer
==========

.. currentmodule:: drf_turbo

.. autoclass:: BaseSerializer
   :members:

.. autoclass:: Serializer
   :show-inheritance:
   :inherited-members:
   :members:
   
.. autoclass:: ModelSerializer
   :show-inheritance:
   :inherited-members:
   :members:

Fields
======

.. autoclass:: Field
   :members:

.. autoclass:: drf_turbo.StrField
   :members:
   
.. autoclass:: drf_turbo.EmailField
   :members:
   
.. autoclass:: drf_turbo.URLField
   :members:
   
.. autoclass:: drf_turbo.RegexField
   :members:
   
.. autoclass:: drf_turbo.IPField
   :members:
   
.. autoclass:: drf_turbo.UUIDField
   :members:
    
.. autoclass:: drf_turbo.PasswordField
   :members:

.. autoclass:: drf_turbo.SlugField
   :members:

.. autoclass:: IntField
   :members:

.. autoclass:: FloatField
   :members:

.. autoclass:: DecimalField
   :members:
   
.. autoclass:: BoolField
   :members:

.. autoclass:: ChoiceField
   :members:
   
.. autoclass:: MultipleChoiceField
   :members:
   
.. autoclass:: DateTimeField
   :members:

.. autoclass:: DateField
   :members:
   
.. autoclass:: TimeField
   :members:
   
.. autoclass:: FileField
   :members:

.. autoclass:: ArrayField
   :members:
   
.. autoclass:: DictField
   :members:

.. autoclass:: JSONField
   :members:   
   
.. autoclass:: RelatedField
   :members:
   
.. autoclass:: ManyRelatedField
   :members:

.. autoclass:: ConstantField
   :members:
   
.. autoclass:: RecursiveField
   :members:
   
.. autoclass:: MethodField
   :members:
